hamed_advanced_mode
=========================

.. image:: https://img.shields.io/pypi/v/hamed_advanced.svg
   :target: https://pypi.python.org/pypi/hamed_advanced
.. image:: https://api.travis-ci.org/yeleman/hamed-advanced.svg
   :target: https://travis-ci.org/yeleman/hamed-advanced


Simple caesar cipher for enabling-disabling advanced mode in hamed
